# project4

A project with Odoo addons grouped in several directories, using the odoo/addons layout,
with additional packages in the `src` directory.

This is the recommended layout for large projects where there are to many addons to
comfortably handle in one directory.
